@@ -37,6 +37,18 @@ if FOAM_BRANCH_VERSION( "dev", ">=", "010600" ):
     pass
 
     
+#--------------------------------------------------------------------------------------
+if FOAM_VERSION( ">=", "020000" ):
+    from pimpleFlux.r2_0_0 import *
+    pass
+
+    
+#--------------------------------------------------------------------------------------
+if FOAM_VERSION( ">=", "020100" ):
+    from pimpleFlux.r2_1_0 import *
+    pass
+
+    
 #--------------------------------------------------------------------------------------
 def entry_point():
     try:
